@@ -8,23 +8,31 @@ import deprecation
 import darwin.datatypes as dt
 from darwin.version import __version__
 
-DEPRECATION_MESSAGE = """This function is going to be turned into private. This means that breaking 
-changes in its interface and implementation are to be expected. We encourage using ``export`` 
-instead of calling this low-level function directly."""
+DEPRECATION_MESSAGE = """
 
-REMOVAL_MESSAGE = """This function is going to be removed. This means that breaking 
-changes in its interface and implementation are to be expected. We encourage no longer using it."""
+This function is going to be turned into private. This means that breaking 
+changes in its interface and implementation are to be expected. We encourage using ``export`` 
+instead of calling this low-level function directly.
+
+"""
+
+REMOVAL_MESSAGE = """
+
+This function is going to be removed. This means that breaking 
+changes in its interface and implementation are to be expected. We encourage no longer using it.
+
+"""
 
 
 def export(annotation_files: Iterable[dt.AnnotationFile], output_dir: Path) -> None:
     """
-    Exports the given ``AnnotationFile``s into the pascalvoc format inside of the given
+    Exports the given ``AnnotationFile``\\s into the pascalvoc format inside of the given
     ``output_dir``.
 
     Parameters
     ----------
     annotation_files : Iterable[dt.AnnotationFile]
-        The ``AnnotationFile``s to be exported.
+        The ``AnnotationFile``\\s to be exported.
     output_dir : Path
         The folder where the new pascalvoc files will be.
     """
